@@ -10,7 +10,7 @@ except ImportError:
 from django.contrib.staticfiles import finders
 from django.contrib.staticfiles.storage import staticfiles_storage
 from django.core.files.base import ContentFile
-from django.utils.encoding import smart_str, smart_bytes
+from django.utils.encoding import smart_bytes
 
 from pipeline.conf import settings
 from pipeline.exceptions import CompilerError
@@ -72,7 +72,7 @@ class CompilerBase(object):
         raise NotImplementedError
 
     def save_file(self, path, content):
-        return self.storage.save(path, ContentFile(smart_str(content)))
+        return self.storage.save(path, ContentFile(smart_bytes(content)))
 
     def read_file(self, path):
         file = self.storage.open(path, 'rb')
@@ -81,6 +81,8 @@ class CompilerBase(object):
         return content
 
     def is_outdated(self, infile, outfile):
+        if not self.storage.exists(outfile):
+            return True
         try:
             return self.storage.modified_time(infile) > self.storage.modified_time(outfile)
         except (OSError, NotImplementedError):
