@@ -6,7 +6,7 @@ from pipeline.compressors import SubProcessCompressor
 
 class UglifyJSCompressor(SubProcessCompressor):
     def compress_js(self, js):
-        command = '%s -nc %s' % (settings.PIPELINE_UGLIFYJS_BINARY, settings.PIPELINE_UGLIFYJS_ARGUMENTS)
+        command = '%s %s' % (settings.PIPELINE_UGLIFYJS_BINARY, settings.PIPELINE_UGLIFYJS_ARGUMENTS)
         if self.verbose:
             command += ' --verbose'
         return self.execute_command(command, js)
