@@ -9,7 +9,7 @@ try:
 except ImportError:
     from urllib import quote
 
-from django.utils.encoding import smart_str
+from django.utils.encoding import smart_text
 
 from pipeline.conf import settings
 
@@ -27,7 +27,7 @@ def to_class(class_str):
 def filepath_to_uri(path):
     if path is None:
         return path
-    return quote(smart_str(path).replace("\\", "/"), safe="/~!*()'#?")
+    return quote(smart_text(path).replace("\\", "/"), safe="/~!*()'#?")
 
 
 def guess_type(path, default=None):
@@ -36,7 +36,7 @@ def guess_type(path, default=None):
     mimetype, _ = mimetypes.guess_type(path)
     if not mimetype:
         return default
-    return smart_str(mimetype)
+    return smart_text(mimetype)
 
 
 def relpath(path, start=posixpath.curdir):
