@@ -1,7 +1,7 @@
 # -*- coding: utf-8 flake8: noqa -*-
 from .test_compiler import *
 from .test_compressor import *
-from .test_extension import *
+from .test_template import *
 from .test_glob import *
 from .test_middleware import *
 from .test_packager import *
