@@ -4,6 +4,8 @@ from django.test import TestCase
 
 from pipeline.conf import settings
 from pipeline.compilers import Compiler, CompilerBase
+from pipeline.collector import default_collector
+
 
 from tests.utils import _
 
@@ -20,6 +22,7 @@ class DummyCompiler(CompilerBase):
 
 class CompilerTest(TestCase):
     def setUp(self):
+        default_collector.collect()
         self.compiler = Compiler()
         self.old_compilers = settings.PIPELINE_COMPILERS
         settings.PIPELINE_COMPILERS = ['tests.tests.test_compiler.DummyCompiler']
@@ -40,4 +43,5 @@ class CompilerTest(TestCase):
         self.assertEqual([_('pipeline/js/dummy.js'), _('pipeline/js/application.js')], list(paths))
 
     def tearDown(self):
+        default_collector.clear()
         settings.PIPELINE_COMPILERS = self.old_compilers
